angular.module('metro-romance')

    .factory('ApiService', function ($http, $q, $cordovaDevice, $ionicPlatform) {

        var CODE = "3dZrj",
            PROD = 'https://serene-cliffs-10627.herokuapp.com',
            TEST = 'https://metro-romance-test.herokuapp.com';
        var dbUrl = TEST;

        var deviceUUID;

        $ionicPlatform.ready(function () {
            deviceUUID = $cordovaDevice.getUUID();
            console.log('device', ionic.Platform.device());
        });

        return {
            getLocations: function () {
                var params = {
                    code: CODE
                }
                return $http.get(dbUrl + '/location', { params: params })
            },

            checkLocation: function (lat, lon, range) {
                var params = {
                    latitude: lat,
                    longitude: lon,
                    range: range,
                    code: CODE
                }
                return $http.get(dbUrl + '/checkLocation', { params: params })
            },

            getMission: function (locationID, userData) {
                var deferred = $q.defer();
                var params = {
                    locationID: locationID,
                    complete_missions: userData.mission,
                    code: CODE
                }
                $http.post(dbUrl + '/mission', params)
                    .then(function (res) {

                        if (Object.keys(res.data).length > 0) {
                            if (!!res.data.error && res.data.error === "no mission found") {
                                deferred.resolve(res);
                                return false
                            }
                            if (res.data.mission.missionID === 'KSM0001') {
                                res.data.dialog.Low = res.data.dialog.High;
                                res.data.dialog.Mid = res.data.dialog.High;
                            }
                            if (res.data.mission.missionID === 'KSM0023') {
                                res.data.dialog.Low = res.data.dialog.High;
                                res.data.dialog.Mid = res.data.dialog.High;
                            }

                            if (res.data.mission.missionID === 'KSM0024') {
                                res.data.dialog.High = res.data.dialog.Low;
                                res.data.dialog.Mid = res.data.dialog.Low;
                            }
                        }
                        deferred.resolve(res);
                        return false;
                    })
                return deferred.promise;
            },

            getRandomMission: function () {
                var deferred = $q.defer();
                $http.get(dbUrl + '/random')
                    .then(function (res) {
                        var _data = res.data;
                        var newData = Object.keys(_data).map(function (objKey, index) {
                            var value = _data[objKey];
                            return {
                                character: value["character"][0],
                                question: value["question"],
                                select: value["select"],
                            }
                        });
                        deferred.resolve({ data: newData });
                    });

                return deferred.promise;
            },

            getUserData: function () {
                var deferred = $q.defer();
                var data = {
                    deviceId: deviceUUID,
                    code: CODE
                }
                $http.post(dbUrl + '/user_data', data)
                    .then(function (res) {
                        if (!res.data.User.unlockLocation) {
                            res.data.User.unlockLocation = [];
                        }
                        deferred.resolve(res);
                    })
                return deferred.promise;
            },

            updateUserData: function (userData) {
                userData.deviceId = deviceUUID
                var data = {
                    User: userData,
                    code: CODE
                };
                return $http.post(dbUrl + '/update_user', data)
            },

            getAllItems: function () {
                var params = {
                    code: CODE
                }
                return $http.get(dbUrl + '/items', { params: params });
            },

            getAllNotifications: function () {
                var params = {
                    code: CODE
                }
                var deferred = $q.defer();
                $http.get(dbUrl + '/missiontips', { params: params })
                    .then(function (res) {
                        res.data["KSM0001"].content[0]["Low"] = res.data["KSM0001"].content[0]["High"];
                        res.data["KSM0001"].content[0]["Mid"] = res.data["KSM0001"].content[0]["High"];
                        deferred.resolve(res)
                    });
                return deferred.promise;
            },
            getNewNotifications: function () {
                var params = {
                    code: CODE
                }
                var deferred = $q.defer();
                $http.get(dbUrl + '/newMissionTips', { params: params })
                    .then(function (res) {
                        var startHigh = res.data.filter(function (_m) {
                            return _m.mission === "KSM0001"
                        })[0];
                        var startMid = Object.assign({},startHigh);
                        var startLow = Object.assign({},startHigh);
                        startMid.vibe = "Mid";
                        startLow.vibe = "Low";
                        res.data.push(startMid, startLow);
                        console.log('start',startHigh, startMid, startLow);
                        deferred.resolve(res)
                    });
                return deferred.promise;
            },

            updateUserFB: function (fbid) {
                console.log("updateUserFB");

                var params = {
                    deviceId: deviceUUID,
                    facebookId: fbid,
                    code: CODE
                }
                return $http.post(dbUrl + '/update_user_fb', params);
            },


            checkPreRegister: function () {
                console.log("check pre");
                var fbid = localStorage.getItem('facebookId');
                console.log(fbid);
                var params = {
                    fbid: fbid,
                    code: CODE
                }
                return $http.post(dbUrl + '/check_pre_register', params);
            }


        }
    });
