
var ks = {
	loaded: false,
	trackableVisible: false,
	iniEnabled: false,
	init: function initFn(iniEnabled) {
		this.iniEnabled = iniEnabled;
		this.createOverlays();
	},

	createOverlays: function createOverlaysFn() {
		/*
			First an AR.Tracker needs to be created in order to start the recognition engine. It is initialized with a URL specific to the target collection. Optional parameters are passed as object in the last argument. In this case a callback function for the onLoaded trigger is set. Once the tracker is fully loaded the function loadingStep() is called.

			Important: If you replace the tracker file with your own, make sure to change the target name accordingly.
			Use a specific target name to respond only to a certain target or use a wildcard to respond to any or a certain group of targets.
		*/


		this.tracker = new AR.ClientTracker("assets/krt2.wtc", {
			onTargetsLoaded: this.ksLoaded,
			onLoaded: this.loadingStep,
			enabled: iniEnabled
		});

		var _scale = { x: 0.0012, y: 0.0012, z: 0.0012 };
		var _rotate = { roll: 0, tilt: 270, heading: 0 };

		/*
			3D content within Wikitude can only be loaded from Wikitude 3D Format files (.wt3). This is a compressed binary format for describing 3D content which is optimized for fast loading and handling of 3D content on a mobile device. You still can use 3D models from your favorite 3D modeling tools (Autodesk® Maya® or Blender) but you'll need to convert them into the wt3 file format. The Wikitude 3D Encoder desktop application (Windows and Mac) encodes your 3D source file. You can download it from our website. The Encoder can handle Autodesk® FBX® files (.fbx) and the open standard Collada (.dae) file formats for encoding to .wt3. 

			Create an AR.Model and pass the URL to the actual .wt3 file of the model. Additional options allow for scaling, rotating and positioning the model in the scene.

			A function is attached to the onLoaded trigger to receive a notification once the 3D model is fully loaded. Depending on the size of the model and where it is stored (locally or remotely) it might take some time to completely load and it is recommended to inform the user about the loading time.
		*/

		//var img85SkyTower = new AR.ImageResource("");

		this.SoraModel = new AR.Model("assets/sora.wt3", { //assets/car_animated.wt3
			onLoaded: this.loadingStep,
			scale: _scale,
			translate: { x: 0.1, y: -1, z: 0.2 },
			rotate: _rotate
		});

		this.ArtModel = new AR.Model("assets/art.wt3", { //assets/car_animated.wt3
			onLoaded: this.loadingStep,
			scale: _scale,
			translate: { x: 0.1, y: -1, z: 0.2 },
			rotate: _rotate
		});

		var imgFKL4 = new AR.ImageResource("KRT_img/ar/Midori_Sora_happy_normal_ar.png");
		var imgFKL5 = new AR.ImageResource("KRT_img/ar/Feiyong_Midori_happy_ar.png");
		var imgFKL6 = new AR.ImageResource("KRT_img/ar/Midori_Nana_normal_ar.png");
/*
		var overlay85SkyTower = new AR.ImageDrawable(img85SkyTower, 1, {
			offsetX: -0.15,
			offsetY: -1.65,
			scale: 3.6

		});
		*/
		var overlayFKL4 = new AR.ImageDrawable(imgFKL4, 1, {
			offsetX: -0.15,
			offsetY: -0.85,
			scale: 3.9
		});

		var overlayFKL5 = new AR.ImageDrawable(imgFKL5, 1, {
			offsetX: -0.15,
			offsetY: -0.85,
			scale: 3.9
		});
		var overlayFKL6 = new AR.ImageDrawable(imgFKL6, 1, {
			offsetX: -0.15,
			offsetY: -0.85,
			scale: 3.9
		});

		this.appearingAnimationSora = this.createAppearingAnimation(this.SoraModel, 0.288);
		this.animationRunSora = new AR.ModelAnimation(this.SoraModel, "Animation_00");

		this.appearingAnimationArt = this.createAppearingAnimation(this.ArtModel, 0.144);
		this.animationRunArt = new AR.ModelAnimation(this.ArtModel, "Take 001");
		/*
			The last line combines everything by creating an AR.Trackable2DObject with the previously created tracker, the name of the image target and the drawable that should augment the recognized image.
			Please note that in this case the target name is a wildcard. Wildcards can be used to respond to any target defined in the target collection. If you want to respond to a certain target only for a particular AR.Trackable2DObject simply provide the target name as specified in the target collection.
		*/
		//85SkyTower_AR_Target_Special
		//CanalCity_ARTarget_03 //拉麵 //FKL4
		//CanalCity_ARTarget_02 //FKL5
		//CanalCity_ARTarget_01 //衣服 FKL6

		var pageFKL4 = new AR.Trackable2DObject(this.tracker, "CanalCity_ARTarget_03", {
			drawables: {
				cam: overlayFKL4
			},
			onClick: function () {
				document.location = 'architectsdk://action=FKL4';
			},
			onEnterFieldOfVision: function () {

			}
		});

		var pageFKL5 = new AR.Trackable2DObject(this.tracker, "CanalCity_ARTarget_01", {
			drawables: {
				cam: overlayFKL5
			},
			onClick: function () {
				document.location = 'architectsdk://action=FKL5';
			},
			onEnterFieldOfVision: function () {

			}
		});
		var pageFKL6 = new AR.Trackable2DObject(this.tracker, "CanalCity_ARTarget_02", {
			drawables: {
				cam: overlayFKL6
			},
			onClick: function () {
				document.location = 'architectsdk://action=FKL6';
			},
			onEnterFieldOfVision: function () {

			}
		});

		var $arTargetSign = $('.arTargetSign');
		var $ar2d = $('.ARimg');

		var page85SkyTower = new AR.Trackable2DObject(this.tracker, "85SkyTower_AR_Target_Special", {
			drawables: {
				cam: [this.SoraModel]
			},
			onClick: function () {
				document.location = 'architectsdk://action=85SkyTower';
			},
			onEnterFieldOfVision: function () {
				ks.trackableVisible = true;
				$arTargetSign.hide();
				if (ks.loaded) {
					ks.appearingAnimationSora.start();
					ks.animationRunSora.start();
				}
			},
			onExitFieldOfVision: function () {
				if ($ar2d.is(":visible")) {
					$arTargetSign.hide();
				} else {
					$arTargetSign.show();
				}
				ks.trackableVisible = false;
			}
		});

		var pageYueyue = new AR.Trackable2DObject(this.tracker, "YueYue_AR_Target", {
			drawables: {
				cam: [this.ArtModel]
			},
			onClick: function () {
				document.location = 'architectsdk://action=YueYue';
			},
			onEnterFieldOfVision: function () {
				ks.trackableVisible = true;
				$arTargetSign.hide();
				if (ks.loaded) {
					ks.appearingAnimationArt.start();
					ks.animationRunArt.start();
				}
			},
			onExitFieldOfVision: function () {
				if ($ar2d.is(":visible")) {
					$arTargetSign.hide();
				} else {
					$arTargetSign.show();
				}
				ks.trackableVisible = false;
			}
		});

		$('#arClose').click(function () {
			document.location = 'architectsdk://action=leave';
		});
	
		$('#arFindTarget').click(function () {
			this.tracker.enabled = !this.tracker.enabled;
			if ($ar2d.is(":visible")) {
				$ar2d.hide();
			} else {
				$ar2d.show();
			}

			if ($ar2d.is(":visible")) {
				$arTargetSign.hide();
			} else {
				$arTargetSign.show();
			}

		}.bind(this));

		$('body').height($(window).height());

		$ar2d.click(function () {
			var locationID = localStorage.getItem('ks-locationID');
			document.location = 'architectsdk://action=' + locationID;
		});
	},

	loadingStep: function loadingStepFn() {
		if (!ks.loaded && ks.tracker.isLoaded() && ks.SoraModel.isLoaded()) {
			var e = document.getElementById('loadingMessage');
			e.parentElement.removeChild(e);
			ks.loaded = true;
		}
	},

	createAppearingAnimation: function createAppearingAnimationFn(model, scale, vertical) {
		/*
			The animation scales up the 3D model once the target is inside the field of vision. Creating an animation on a single property of an object is done using an AR.PropertyAnimation. Since the car model needs to be scaled up on all three axis, three animations are needed. These animations are grouped together utilizing an AR.AnimationGroup that allows them to play them in parallel.

			Each AR.PropertyAnimation targets one of the three axis and scales the model from 0 to the value passed in the scale variable. An easing curve is used to create a more dynamic effect of the animation.
		*/
		var sx = new AR.PropertyAnimation(model, "scale.x", 0, scale, 1500, {
			type: AR.CONST.EASING_CURVE_TYPE.EASE_OUT_ELASTIC
		});
		var sy = new AR.PropertyAnimation(model, "scale.y", 0, scale, 1500, {
			type: AR.CONST.EASING_CURVE_TYPE.EASE_OUT_ELASTIC
		});
		var sz = new AR.PropertyAnimation(model, "scale.z", 0, scale, 1500, {
			type: AR.CONST.EASING_CURVE_TYPE.EASE_OUT_ELASTIC
		});

		return new AR.AnimationGroup(AR.CONST.ANIMATION_GROUP_TYPE.PARALLEL, [sx, sy, sz]);
	},

	appear: function appearFn() {
		ks.trackableVisible = true;
		if (ks.loaded) {
			// Resets the properties to the initial values.
			//ks.resetModel();
			ks.appearingAnimationSora.start();
		}
	},

	disappear: function disappearFn() {
		ks.trackableVisible = false;

	},

	ksLoaded: function ksLoadedFn() {
		return false
	}


};